import { renderless, api } from '@opentinyvue/vue-renderless/switch/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "switch-default": "inline-block align-middle transition-all duration-200 ease-in-out rounded-full relative outline-0",
  "switch-small": "w-10 h-6 sm:w-9 sm:h-5",
  "switch-mini": "w-8 h-5 sm:w-7 sm:h-4",
  "switch-medium": "w-10 h-6",
  "switch-handle-default": 'before:content-[""] before:rounded-full before:bg-color-bg-1 before:absolute before:cursor-pointer before:transition-all before:duration-200 before:ease-in-out before:text-center before:top-0.5',
  "switch-handle-small": "before:w-5 before:h-5 before:sm:w-4 before:sm:h-4",
  "switch-handle-mini": "before:w-4 before:h-4 before:sm:w-3 before:sm:h-3",
  "switch-handle-medium": "before:w-5 before:h-5",
  "switch-true-disabled": "bg-color-brand-disabled cursor-not-allowed",
  "switch-false-disabled": "bg-color-border-separator cursor-not-allowed",
  "switch-true-not-disabled": "before:[&_span:nth-of-type(1)]:shadow-xsm bg-color-brand cursor-pointer",
  "switch-false-not-disabled": "before:[&_span:nth-of-type(1)]:shadow-xsm bg-color-icon-disabled cursor-pointer",
  "switch-handle-false-small": "before:left-0.5",
  "switch-handle-false-medium": "before:left-0.5",
  "switch-handle-false-mini": "before:left-0.5",
  "switch-handle-false-small-disabled": "before:left-0.5",
  "switch-handle-false-medium-disabled": "before:left-0.5",
  "switch-handle-false-mini-disabled": "before:left-0.5",
  "switch-handle-true-small": "before:left-4.5",
  "switch-handle-true-medium": "before:left-4.5",
  "switch-handle-true-mini": "before:left-3.5",
  "switch-handle-true-small-disabled": "before:left-4.5",
  "switch-handle-true-medium-disabled": "before:left-4.5",
  "switch-handle-true-mini-disabled": "before:left-3.5",
  "switch-inner-default": "absolute transition-all duration-200 ease-in-out text-color-bg-1 flex items-center justify-center top-0.5",
  "switch-inner-small": "w-5 h-5 sm:w-4 sm:h-4",
  "switch-inner-mini": "w-4 h-4 sm:w-3 sm:h-3",
  "switch-inner-medium": "w-5 h-5",
  "switch-inner-true-word": "left-px",
  "switch-inner-false-small-word": "left-4.5",
  "switch-inner-false-medium-word": "left-4.5",
  "switch-inner-false-mini-word": "left-3.5",
  "switch-inner-false-icon": "left-0.5",
  "switch-inner-true-small-icon": "left-4.5",
  "switch-inner-true-medium-icon": "left-4.5",
  "switch-inner-true-mini-icon": "left-3.5",
  "switch-icon-small": "w-4 h-4 sm:w-3 sm:h-3",
  "switch-icon-medium": "w-4 h-4",
  "switch-icon-mini": "w-3 h-3 sm:w-2 sm:h-2",
  "switch-icon-false-disabled": "fill-color-border-separator",
  "switch-icon-false-default": "fill-color-icon-disabled",
  "switch-icon-true-disabled": "fill-color-brand-disabled",
  "switch-icon-true-default": "fill-color-brand",
  "switch-loading-small": "w-5 h-5 sm:w-4 sm:h-4",
  "switch-loading-medium": "w-5 h-5",
  "switch-loading-mini": "w-4 h-4 sm:w-3 sm:h-3 "
};
var __vue2_script = defineComponent({
  emits: ["change", "update:modelValue"],
  props: [].concat(props, ["modelValue", "trueValue", "falseValue", "disabled", "size", "tabindex", "types"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("span", {
    class: _vm.m(_vm.gcls("switch-default"), _vm.gcls("switch-" + (_vm.size ? _vm.size : "small")), _vm.gcls((_vm.state.currentValue === _vm.trueValue ? "switch-true" : "switch-false") + (_vm.state.disabled || _vm.types === "loading" ? "-disabled" : "-not-disabled"))),
    attrs: {
      "data-tag": "tiny-switch",
      "tabindex": _vm.tabindex
    },
    on: {
      "click": _vm.toggle,
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "space", 32, $event.key, [" ", "Spacebar"])) return null;
        return _vm.toggle.apply(null, arguments);
      }
    }
  }, [_c("span", {
    class: _vm.m(_vm.gcls("switch-handle-default"), _vm.gcls("switch-handle-" + (_vm.size ? _vm.size : "small")), _vm.gcls(_vm.state.currentValue === _vm.trueValue ? "switch-handle-true-" + (_vm.size ? _vm.size : "small") + (_vm.state.disabled || _vm.types === "loading" ? "-disabled" : "") : "switch-handle-false-" + (_vm.size ? _vm.size : "small") + (_vm.state.disabled || _vm.types === "loading" ? "-disabled" : ""))),
    attrs: {
      "data-tag": "tiny-switch-handle"
    }
  }), _c("span", {
    class: _vm.m(_vm.gcls("switch-inner-default"), _vm.gcls("switch-inner-" + (_vm.size ? _vm.size : "small")), _vm.gcls(_vm.state.currentValue === _vm.trueValue ? _vm.types === "word" ? "switch-inner-true-word" : "switch-inner-true-" + (_vm.size ? _vm.size : "small") + "-icon" : _vm.types === "word" ? "switch-inner-false-" + (_vm.size ? _vm.size : "small") + "-word" : "switch-inner-false-icon")),
    attrs: {
      "data-tag": "tiny-switch-inner"
    }
  }, [_vm.types === "word" ? _c("div", {
    staticClass: "sm:text-xs text-sm",
    attrs: {
      "data-tag": "tiny-switch-word"
    }
  }, [_vm.state.currentValue === _vm.trueValue ? _vm._t("open", function() {
    return [_vm._v(_vm._s(_vm.t("yes")))];
  }) : _vm._e(), _vm.state.currentValue === _vm.falseValue ? _vm._t("close", function() {
    return [_vm._v(_vm._s(_vm.t("no")))];
  }) : _vm._e()], 2) : _vm._e(), _vm.types === "icon" ? _c("div", {
    attrs: {
      "data-tag": "tiny-switch-icon"
    }
  }, [_vm.state.currentValue === _vm.trueValue ? _vm._t("open", function() {
    return [_c("svg", {
      class: [_vm.gcls("switch-icon-" + (_vm.size ? _vm.size : "small")), _vm.gcls("switch-icon-true-" + (_vm.state.disabled ? "disabled" : "default"))],
      attrs: {
        "viewBox": "0 0 24 24"
      }
    }, [_c("path", {
      attrs: {
        "d": "M9.9 15.6l9.4-9.4c.4-.4 1-.4 1.4 0 .4.4.4 1 0 1.4l-10 10.1c-.4.4-1 .4-1.4 0-.1 0-.1-.1-.2-.1l-5.8-5.8c-.4-.4-.4-1 0-1.4.4-.4 1-.4 1.4 0l5.2 5.2z"
      }
    })])];
  }) : _vm._e(), _vm.state.currentValue === _vm.falseValue ? _vm._t("close", function() {
    return [_c("svg", {
      class: [_vm.gcls("switch-icon-" + (_vm.size ? _vm.size : "small")), _vm.gcls("switch-icon-false-" + (_vm.state.disabled ? "disabled" : "default"))],
      attrs: {
        "viewBox": "0 0 24 24"
      }
    }, [_c("path", {
      attrs: {
        "d": "M13.4 12l6.3-6.3c.4-.4.4-1 0-1.4-.4-.4-1-.4-1.4 0L12 10.6 5.7 4.3c-.4-.4-1-.4-1.4 0-.4.4-.4 1 0 1.4l6.3 6.3-6.3 6.3c-.4.4-.4 1 0 1.4.2.2.4.3.7.3.3 0 .5-.1.7-.3l6.3-6.3 6.3 6.3c.2.2.4.3.7.3s.5-.1.7-.3c.4-.4.4-1 0-1.4L13.4 12z"
      }
    })])];
  }) : _vm._e()], 2) : _vm._e(), _vm.types === "loading" ? _c("div", {
    attrs: {
      "data-tag": "tiny-switch-loading"
    }
  }, [_vm.state.currentValue === _vm.trueValue ? _vm._t("open", function() {
    return [_c("svg", {
      class: [_vm.gcls("switch-loading-" + (_vm.size ? _vm.size : "small")), _vm.gcls("switch-icon-true-disabled")],
      attrs: {
        "viewBox": "0 0 48 48"
      }
    }, [_c("path", {
      attrs: {
        "d": "M43.935,25.145c0-10.318-8.364-18.683-18.683-18.683c-10.318,0-18.683,8.365-18.683,18.683h4.068c0-8.071,6.543-14.615,14.615-14.615c8.072,0,14.615,6.543,14.615,14.615H43.935z",
        "transform": "rotate(275.098 75 75)"
      }
    }, [_c("animateTransform", {
      attrs: {
        "attributeType": "xml",
        "attributeName": "transform",
        "type": "rotate",
        "from": "0 25 25",
        "to": "360 25 25",
        "dur": "1s",
        "repeatCount": "indefinite"
      }
    })], 1)])];
  }) : _vm._e(), _vm.state.currentValue === _vm.falseValue ? _vm._t("close", function() {
    return [_c("svg", {
      class: [_vm.gcls("switch-loading-" + (_vm.size ? _vm.size : "small")), _vm.gcls("switch-icon-false-disabled")],
      attrs: {
        "viewBox": "0 0 48 48"
      }
    }, [_c("path", {
      attrs: {
        "d": "M43.935,25.145c0-10.318-8.364-18.683-18.683-18.683c-10.318,0-18.683,8.365-18.683,18.683h4.068c0-8.071,6.543-14.615,14.615-14.615c8.072,0,14.615,6.543,14.615,14.615H43.935z",
        "transform": "rotate(275.098 75 75)"
      }
    }, [_c("animateTransform", {
      attrs: {
        "attributeType": "xml",
        "attributeName": "transform",
        "type": "rotate",
        "from": "0 25 25",
        "to": "360 25 25",
        "dur": "1s",
        "repeatCount": "indefinite"
      }
    })], 1)])];
  }, {
    "dataTag": "tiny-switch-close"
  }) : _vm._e()], 2) : _vm._e()])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
